==> blancoStringGroup-0.1.1-src.zip: blancoStringGroup/blanco.cs/main/blanco/sample/stringgroup/SampleStringGroup.cs <==
// ̃\[XR[h blanco FrameworkɂĎĂ܂B
using System;

namespace blanco.sample.stringgroup
{
    /// <summary>O[ṽTvB̃NX͒PɃTvłBۂ̓ɂ͗p܂B</summary>
    public class SampleStringGroup
    {
        /// <summary>No.1 :At@xbg̕`B</summary>
        public static int ABCDEFG = 1;

        /// <summary>No.2 :Sp̕`B</summary>
        public static int AIUEO = 2;

        /// <summary>No.3 :VONI[gWJ邱Ƃ̊mFB</summary>
        public static int QUOTE = 3;

        /// <summary>No.4 :_uNI[gWJ邱Ƃ̊mFB</summary>
        public static int DOUBLE_QUOTE = 4;

        /// <summary>No.5 :obNXbVWJ邱Ƃ̊mFB</summary>
        public static int BACK_SLASH = 5;

        /// <summary>No.7 </summary>
        public static int WITHOUT_DESC = 7;

        /// <summary>No.8 :r̋󔒂K؂ɏ邱Ƃ̊mFB</summary>
        public static int TEST_SPACE = 8;

        /// <summary>`BO[vȊO̕܂͒萔`̂́B</summary>
        public static int NOT_DEFINED = -1;

        /// <summary>O[vɊ܂܂镶ł邩ǂ𔻒肵܂B</summary>
        /// <param name="argCheck">`FbNsB</param>
        /// <returns>O[vɊ܂܂ĂtureBO[vɊ܂܂ȂłfalseB</returns>
        public bool Match(string argCheck)
        {
            // No.1
            // :At@xbg̕`B
            if ("ABCDEFG".Equals(argCheck)) {
                return true;
            }
            // No.2
            // :Sp̕`B
            if ("".Equals(argCheck)) {
                return true;
            }
            // No.3
            // :VONI[gWJ邱Ƃ̊mFB
            if ("'".Equals(argCheck)) {
                return true;
            }
            // No.4
            // :_uNI[gWJ邱Ƃ̊mFB
            if ("\"".Equals(argCheck)) {
                return true;
            }
            // No.5
            // :obNXbVWJ邱Ƃ̊mFB
            if ("\\".Equals(argCheck)) {
                return true;
            }
            // No.6
            // :萔ȗꂽ`B
            if ("STRING ONLY".Equals(argCheck)) {
                return true;
            }
            // No.7
            if ("ȗ".Equals(argCheck)) {
                return true;
            }
            // No.8
            // :r̋󔒂K؂ɏ邱Ƃ̊mFB
            if ("ABC DEF".Equals(argCheck)) {
                return true;
            }
            return false;
        }

        /// <summary>O[vɊ܂܂镶ł邩ǂA啶ʂ肵܂B</summary>
        /// <param name="argCheck">`FbNsB</param>
        /// <returns>O[vɊ܂܂ĂtureBO[vɊ܂܂ȂłfalseB</returns>
        public bool MatchIgnoreCase(string argCheck)
        {
            // No.1
            // :At@xbg̕`B
            if ("ABCDEFG".Equals(argCheck, StringComparison.CurrentCultureIgnoreCase)) {
                return true;
            }
            // No.2
            // :Sp̕`B
            if ("".Equals(argCheck, StringComparison.CurrentCultureIgnoreCase)) {
                return true;
            }
            // No.3
            // :VONI[gWJ邱Ƃ̊mFB
            if ("'".Equals(argCheck, StringComparison.CurrentCultureIgnoreCase)) {
                return true;
            }
            // No.4
            // :_uNI[gWJ邱Ƃ̊mFB
            if ("\"".Equals(argCheck, StringComparison.CurrentCultureIgnoreCase)) {
                return true;
            }
            // No.5
            // :obNXbVWJ邱Ƃ̊mFB
            if ("\\".Equals(argCheck, StringComparison.CurrentCultureIgnoreCase)) {
                return true;
            }
            // No.6
            // :萔ȗꂽ`B
            if ("STRING ONLY".Equals(argCheck, StringComparison.CurrentCultureIgnoreCase)) {
                return true;
            }
            // No.7
            if ("ȗ".Equals(argCheck, StringComparison.CurrentCultureIgnoreCase)) {
                return true;
            }
            // No.8
            // :r̋󔒂K؂ɏ邱Ƃ̊mFB
            if ("ABC DEF".Equals(argCheck, StringComparison.CurrentCultureIgnoreCase)) {
                return true;
            }
            return false;
        }

        /// <summary>񂩂萔ɕϊ܂B</summary>
        /// <remarks>
        /// <newpara>萔`̏ꍇ ^ꂽ񂪕O[vȌꍇɂ NOT_DEFINED ߂܂B</newpara>
        /// </remarks>
        /// <param name="argCheck">ϊsB</param>
        /// <returns>萔ɕϊ̒lB</returns>
        public int ConvertToInt(string argCheck)
        {
            // No.1
            // :At@xbg̕`B
            if ("ABCDEFG".Equals(argCheck)) {
                return ABCDEFG;
            }
            // No.2
            // :Sp̕`B
            if ("".Equals(argCheck)) {
                return AIUEO;
            }
            // No.3
            // :VONI[gWJ邱Ƃ̊mFB
            if ("'".Equals(argCheck)) {
                return QUOTE;
            }
            // No.4
            // :_uNI[gWJ邱Ƃ̊mFB
            if ("\"".Equals(argCheck)) {
                return DOUBLE_QUOTE;
            }
            // No.5
            // :obNXbVWJ邱Ƃ̊mFB
            if ("\\".Equals(argCheck)) {
                return BACK_SLASH;
            }
            // No.7
            if ("ȗ".Equals(argCheck)) {
                return WITHOUT_DESC;
            }
            // No.8
            // :r̋󔒂K؂ɏ邱Ƃ̊mFB
            if ("ABC DEF".Equals(argCheck)) {
                return TEST_SPACE;
            }

            // Y萔܂łB
            return NOT_DEFINED;
        }
    }
}

==> blancoStringGroup-0.1.5-src.zip: blancoStringGroup/blanco.cs/main/blanco/sample/stringgroup/SampleStringGroup.cs <==
// ̃\[XR[h blanco FrameworkɂĎĂ܂B
using System;

namespace blanco.sample.stringgroup
{
    /// <summary>O[ṽTvB̃NX͒PɃTvłBۂ̓ɂ͗p܂B</summary>
    public class SampleStringGroup
    {
        /// <summary>No.1 :At@xbg̕`B</summary>
        public static readonly int ABCDEFG = 1;

        /// <summary>No.2 :Sp̕`B</summary>
        public static readonly int AIUEO = 2;

        /// <summary>No.3 :VONI[gWJ邱Ƃ̊mFB</summary>
        public static readonly int QUOTE = 3;

        /// <summary>No.4 :_uNI[gWJ邱Ƃ̊mFB</summary>
        public static readonly int DOUBLE_QUOTE = 4;

        /// <summary>No.5 :obNXbVWJ邱Ƃ̊mFB</summary>
        public static readonly int BACK_SLASH = 5;

        /// <summary>No.7 </summary>
        public static readonly int WITHOUT_DESC = 7;

        /// <summary>No.8 :r̋󔒂K؂ɏ邱Ƃ̊mFB</summary>
        public static readonly int TEST_SPACE = 8;

        /// <summary>No.9 :~}[NB</summary>
        public static readonly int BATU = 9;

        /// <summary>`BO[vȊO̕܂͒萔`̂́B</summary>
        public static readonly int NOT_DEFINED = -1;

        /// <summary>O[vɊ܂܂镶ł邩ǂ𔻒肵܂B</summary>
        /// <param name="argCheck">`FbNsB</param>
        /// <returns>O[vɊ܂܂ĂtureBO[vɊ܂܂ȂłfalseB</returns>
        public bool Match(string argCheck)
        {
            // No.1
            // :At@xbg̕`B
            if ("ABCDEFG".Equals(argCheck)) {
                return true;
            }
            // No.2
            // :Sp̕`B
            if ("".Equals(argCheck)) {
                return true;
            }
            // No.3
            // :VONI[gWJ邱Ƃ̊mFB
            if ("'".Equals(argCheck)) {
                return true;
            }
            // No.4
            // :_uNI[gWJ邱Ƃ̊mFB
            if ("\"".Equals(argCheck)) {
                return true;
            }
            // No.5
            // :obNXbVWJ邱Ƃ̊mFB
            if ("\\".Equals(argCheck)) {
                return true;
            }
            // No.6
            // :萔ȗꂽ`B
            if ("STRING ONLY".Equals(argCheck)) {
                return true;
            }
            // No.7
            if ("ȗ".Equals(argCheck)) {
                return true;
            }
            // No.8
            // :r̋󔒂K؂ɏ邱Ƃ̊mFB
            if ("ABC DEF".Equals(argCheck)) {
                return true;
            }
            // No.9
            // :~}[NB
            if ("~".Equals(argCheck)) {
                return true;
            }
            return false;
        }

        /// <summary>O[vɊ܂܂镶ł邩ǂA啶ʂ肵܂B</summary>
        /// <param name="argCheck">`FbNsB</param>
        /// <returns>O[vɊ܂܂ĂtureBO[vɊ܂܂ȂłfalseB</returns>
        public bool MatchIgnoreCase(string argCheck)
        {
            // No.1
            // :At@xbg̕`B
            if ("ABCDEFG".Equals(argCheck, StringComparison.CurrentCultureIgnoreCase)) {
                return true;
            }
            // No.2
            // :Sp̕`B
            if ("".Equals(argCheck, StringComparison.CurrentCultureIgnoreCase)) {
                return true;
            }
            // No.3
            // :VONI[gWJ邱Ƃ̊mFB
            if ("'".Equals(argCheck, StringComparison.CurrentCultureIgnoreCase)) {
                return true;
            }
            // No.4
            // :_uNI[gWJ邱Ƃ̊mFB
            if ("\"".Equals(argCheck, StringComparison.CurrentCultureIgnoreCase)) {
                return true;
            }
            // No.5
            // :obNXbVWJ邱Ƃ̊mFB
            if ("\\".Equals(argCheck, StringComparison.CurrentCultureIgnoreCase)) {
                return true;
            }
            // No.6
            // :萔ȗꂽ`B
            if ("STRING ONLY".Equals(argCheck, StringComparison.CurrentCultureIgnoreCase)) {
                return true;
            }
            // No.7
            if ("ȗ".Equals(argCheck, StringComparison.CurrentCultureIgnoreCase)) {
                return true;
            }
            // No.8
            // :r̋󔒂K؂ɏ邱Ƃ̊mFB
            if ("ABC DEF".Equals(argCheck, StringComparison.CurrentCultureIgnoreCase)) {
                return true;
            }
            // No.9
            // :~}[NB
            if ("~".Equals(argCheck, StringComparison.CurrentCultureIgnoreCase)) {
                return true;
            }
            return false;
        }

        /// <summary>񂩂萔ɕϊ܂B</summary>
        /// <remarks>
        /// <newpara>萔`̏ꍇ ^ꂽ񂪕O[vȌꍇɂ NOT_DEFINED ߂܂B</newpara>
        /// </remarks>
        /// <param name="argCheck">ϊsB</param>
        /// <returns>萔ɕϊ̒lB</returns>
        public int ConvertToInt(string argCheck)
        {
            // No.1
            // :At@xbg̕`B
            if ("ABCDEFG".Equals(argCheck)) {
                return ABCDEFG;
            }
            // No.2
            // :Sp̕`B
            if ("".Equals(argCheck)) {
                return AIUEO;
            }
            // No.3
            // :VONI[gWJ邱Ƃ̊mFB
            if ("'".Equals(argCheck)) {
                return QUOTE;
            }
            // No.4
            // :_uNI[gWJ邱Ƃ̊mFB
            if ("\"".Equals(argCheck)) {
                return DOUBLE_QUOTE;
            }
            // No.5
            // :obNXbVWJ邱Ƃ̊mFB
            if ("\\".Equals(argCheck)) {
                return BACK_SLASH;
            }
            // No.7
            if ("ȗ".Equals(argCheck)) {
                return WITHOUT_DESC;
            }
            // No.8
            // :r̋󔒂K؂ɏ邱Ƃ̊mFB
            if ("ABC DEF".Equals(argCheck)) {
                return TEST_SPACE;
            }
            // No.9
            // :~}[NB
            if ("~".Equals(argCheck)) {
                return BATU;
            }

            // Y萔܂łB
            return NOT_DEFINED;
        }
    }
}
